@@ -1,3 +1,4 @@
+import os
 import hailtop.batch as hb
 
 
@@ -28,3 +29,20 @@ def gzip_chain_job(j):
     cmd = f'gzip -c -f {j.ofile} > tmp.gzip.chain.gz; mv tmp.gzip.chain.gz {j.ofile}'
     j.command(cmd)
     return j
+
+
+def tar_job(b, dirpath):
+    j = b.new_job(name=f'tar_job-{os.path.basename(dirpath)}')
+    j.image('gcr.io/daly-neale-sczmeta/hailgenetics-python-dill-pandas:0.1.0')
+    j.cpu(1)
+    j.memory('standard')
+    j.storage('10G')
+    inputdir = b.read_input(dirpath)
+    j.command(f'''
+    dir=`dirname {inputdir}`
+    base=`basename {inputdir}`
+    cd $dir
+    tar -cvzf {j.ofile} $base
+    ''')
+    b.write_output(j.ofile, f'{dirpath}.tar.gz')
+    return(j)
\ No newline at end of file
